==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Search/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Alle emner");
define("_NOCOMMENTS","Ingen kommentarer");
define("_UCOMMENT","Kommentar");
define("_REVIEWS","Administration af anmeldelser");
define("_SEARCHUSERS","Sg i brugerdatabasen");
define("_SEARCHSECTIONS","Sg i Specialsektioner");
define("_SEARCHREVIEWS","Sg i anmeldelser");
define("_SEARCHIN","Sg i");
define("_ARTICLES","Artikler");
define("_ALLAUTHORS","Alle forfattere");
define("_ALL","Alle");
define("_WEEK","uge");
define("_WEEKS","uger");
define("_MONTH","mned");
define("_MONTHS","mneder");
define("_SEARCHON","Sg p:");
define("_SSTORIES","Artikler");
define("_SSECTIONS","Afsnit");
define("_SUSERS","Brugere");
define("_NOMATCHES","Sgningen gave ingen resultater");
define("_PREVMATCHES","forrige resultater");
define("_NEXTMATCHES","nste resultater");
define("_INSECTION","Artikel i sektionen");
define("_NONAME","Intet navn angivet");
define("_SCOMMENTS","Kommentarer");
define("_SEARCHRESULTS","Sgeresultater");
define("_CONTRIBUTEDBY","Indsendt af");
define("_UCOMMENTS","Kommentarer");
define("_MATCHTITLE","Resultater efter overskrift");
define("_MATCHTEXT","Resultater efter artikeltekst");
define("_MATCHBOTH","Resultater efter overskrift og artikeltekst");
define("_SREPLY","Svar");
define("_SREPLIES","Svar");
define("_ATTACHART","Vedhftet artikel");
define("_PAGES","Sider");
define("_REVIEWSCORE","Score til denne anmeldelse");
define("_PAGE","Side");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Search/language/lang-danish.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_ALLTOPICS","Alle emner");
define("_NOCOMMENTS","Ingen kommentarer");
define("_UCOMMENT","Kommentar");
define("_REVIEWS","Administration af anmeldelser");
define("_SEARCHUSERS","Sg i brugerdatabasen");
define("_SEARCHSECTIONS","Sg i Specialsektioner");
define("_SEARCHREVIEWS","Sg i anmeldelser");
define("_SEARCHIN","Sg i");
define("_ARTICLES","Artikler");
define("_ALLAUTHORS","Alle forfattere");
define("_ALL","Alle");
define("_WEEK","uge");
define("_WEEKS","uger");
define("_MONTH","mned");
define("_MONTHS","mneder");
define("_SEARCHON","Sg p:");
define("_SSTORIES","Artikler");
define("_SSECTIONS","Afsnit");
define("_SUSERS","Brugere");
define("_NOMATCHES","Sgningen gave ingen resultater");
define("_PREVMATCHES","forrige resultater");
define("_NEXTMATCHES","nste resultater");
define("_INSECTION","Artikel i sektionen");
define("_NONAME","Intet navn angivet");
define("_SCOMMENTS","Kommentarer");
define("_SEARCHRESULTS","Sgeresultater");
define("_CONTRIBUTEDBY","Indsendt af");
define("_UCOMMENTS","Kommentarer");
define("_MATCHTITLE","Resultater efter overskrift");
define("_MATCHTEXT","Resultater efter artikeltekst");
define("_MATCHBOTH","Resultater efter overskrift og artikeltekst");
define("_SREPLY","Svar");
define("_SREPLIES","Svar");
define("_ATTACHART","Vedhftet artikel");
define("_PAGES","Sider");
define("_REVIEWSCORE","Score til denne anmeldelse");
define("_PAGE","Side");

?>
